#!/bin/bash
set -e

# Source environment variables
source /app/.env

# Set default variables if not provided
ELASTIC_PASSWORD=${ELASTIC_PASSWORD:-cloudron}
STACK_VERSION=${STACK_VERSION:-8.17.3}
CLUSTER_NAME=${CLUSTER_NAME:-cloudron-cluster}
LICENSE=${LICENSE:-basic}

# Ensure data directories exist
mkdir -p /app/data/elasticsearch
mkdir -p /app/data/certs

# Set permissions
chmod -R 777 /app/data

# Check if certificates exist, if not create them
if [ ! -f /app/data/certs/ca.crt ]; then
    echo "Creating certificates..."
    # Create temporary container to generate certificates
    docker run --rm \
        -v /app/data/certs:/usr/share/elasticsearch/config/certs \
        --name es_certs \
        docker.elastic.co/elasticsearch/elasticsearch:${STACK_VERSION} \
        /bin/bash -c "
            elasticsearch-certutil ca --silent --pem -out config/certs/ca.zip &&
            unzip config/certs/ca.zip -d config/certs &&
            elasticsearch-certutil cert --silent --pem -out config/certs/certs.zip --ca-cert config/certs/ca/ca.crt --ca-key config/certs/ca/ca.key --name es01 --dns es01,localhost --ip 127.0.0.1 &&
            unzip config/certs/certs.zip -d config/certs
        "
    echo "Certificates created."
fi

# Start Elasticsearch
echo "Starting Elasticsearch..."
docker run \
    -d \
    --restart=always \
    --name elasticsearch \
    -v /app/data/elasticsearch:/usr/share/elasticsearch/data \
    -v /app/data/certs:/usr/share/elasticsearch/config/certs \
    -e node.name=es01 \
    -e cluster.name=${CLUSTER_NAME} \
    -e discovery.type=single-node \
    -e ELASTIC_PASSWORD=${ELASTIC_PASSWORD} \
    -e bootstrap.memory_lock=true \
    -e xpack.security.enabled=true \
    -e xpack.security.http.ssl.enabled=false \
    -e xpack.license.self_generated.type=${LICENSE} \
    -e xpack.ml.use_auto_machine_memory_percent=true \
    -e "ES_JAVA_OPTS=-Xms512m -Xmx512m" \
    --ulimit memlock=-1:-1 \
    -p 127.0.0.1:9200:9200 \
    -p 127.0.0.1:9300:9300 \
    docker.elastic.co/elasticsearch/elasticsearch:${STACK_VERSION}

# Wait for Elasticsearch to be up
echo "Waiting for Elasticsearch to start..."
until $(curl --output /dev/null --silent --head --fail http://localhost:9200); do
    printf '.'
    sleep 5
done
echo "Elasticsearch is up and running!"

# Keep script running
exec tail -f /dev/null 